/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

interface AuditListReq {
  pageNo: number
  pageSize: number
  endDate?: string
  moduleType?: string
  operationType?: string
  workflowName?: string
  projectName?: string
  resourceType?: string
  startDate?: string
  userName?: string
}

interface AuditItem {
  userName: string
  resource: string
  operation: string
  time: string
  resourceName: string
}

interface AuditListRes {
  totalList: AuditItem[]
  total: number
  totalPage: number
  pageSize: number
  currentPage: number
  start: number
}

interface AuditModelTypeItem {
  code: number
  name: string
  child: AuditModelTypeItem[] | null
}

interface AuditOperationTypeItem {
  code: number
  name: string
}

export {
  AuditListReq,
  AuditListRes,
  AuditModelTypeItem,
  AuditOperationTypeItem
}
